@@ -1,6 +1,6 @@
 use std::collections::BTreeMap;
 
-use tui::widgets::TableState;
+use ratatui::widgets::TableState;
 
 use crate::app::{keymap::Input, ui::UICommand};
 
